angular.module("app_factory", [])
    .factory('$zhmap', ['$window', '$timeout', 'appService', function ($window, $timeout, appService) {
        var factory = {
            ol: $window.ol,
            olLoaded: function (_olLoaded) {
                testOl(this);
                function testOl(zhmap) {
                    if ($window.ol) {
                        console.log('已载入ol');
                        zhmap.ol = $window.ol;
                        _olLoaded && _olLoaded()
                    }
                    else $timeout(function () {
                        console.log('尝试载入ol');
                        testOl()
                    }, 500)
                }
            },
            buildMap: function (sourse) {
                var zhmap = this;
                /* import package */
                var ol = this.ol;
                var Map = ol.Map;
                var View = ol.View;
                var { getWidth, getTopLeft } = ol.extent;
                var TileLayer = ol.layer.Tile;
                var { get, toLonLat, fromLonLat, transformExtent } = ol.proj;
                var getProjection = get;
                var WMTS = ol.source.WMTS;
                var WMTSTileGrid = ol.tilegrid.WMTS;
                var GeoJSON = ol.format.GeoJSON;
                var VectorLayer = ol.layer.Vector;
                var VectorSource = ol.source.Vector;
                var { Fill, Stroke, Style, Text } = ol.style;
                var { bbox } = ol.loadingstrategy;
                var Overlay = ol.Overlay;
                var { toStringHDMS } = ol.coordinate;
                /* core code */
                var matrixSet = 'EPSG:3857';
                var projection = getProjection(matrixSet);
                var projectionExtent = projection.getExtent();
                var size = getWidth(projectionExtent) / 256;
                var matrixIds = [];
                var matrixId = 'EPSG:3857';
                var hasZoomLevel = '21';
                var resolutions = [];
                for (var z = 0; z < hasZoomLevel; ++z) {
                    resolutions[z] = size / Math.pow(2, z);
                    matrixIds[z] = matrixId + ':' + z;
                }
                var vectorStyle = new Style({
                    fill: new Fill({
                        color: 'rgba(255, 255, 255, 0)'
                    }),
                    stroke: new Stroke({
                        color: 'rgba(255, 255, 255, 0.1)',
                        width: 1
                    })
                });
                var vectorLayer = new VectorLayer({
                    opacity: 1,
                    source: new VectorSource({
                        url: function (extent) {
                            return sourse.olVector +
                                'bbox=' + extent.join(',') + ',EPSG:3857';
                        },
                        // projection: projection,
                        format: new GeoJSON(),
                        strategy: bbox
                    }),
                    style: vectorStyle
                });
                var tileLayer = new TileLayer({
                    opacity: 1,
                    source: new WMTS({
                        url: sourse.olTileUrl,
                        // layer: 'tonghua:changan-road--bd-group',
                        layer: sourse.olTile,
                        matrixSet: matrixSet,
                        format: 'image/png',
                        projection: projection,
                        tileGrid: new WMTSTileGrid({
                            origin: getTopLeft(projectionExtent), // 原点（左上角）
                            resolutions: resolutions, // 分辨率数组
                            matrixIds: matrixIds // 矩阵ID，就是瓦片坐标系z维度各个层级的标识
                        }),
                        style: '',
                        wrapX: true
                    })
                });
                var container = document.getElementById('popup');
                var closer = document.getElementById('popup-closer');
                var overlay = new Overlay({
                    element: container,
                    autoPan: true,
                    autoPanAnimation: {
                        duration: 250
                    }
                });
                closer.onclick = function () {
                    selectedFeatures.clear();
                    overlay.setPosition(undefined);
                    closer.blur();
                    return false;
                };
                var map = new Map({
                    layers: [
                        tileLayer, vectorLayer
                    ],
                    target: 'map',
                    overlays: [overlay],
                    view: new View({
                        center: sourse.center,
                        extent: sourse.extents,
                        minZoom: sourse.minZoom || 15,
                        maxZoom: sourse.maxZoom || 21,
                        zoom: sourse.zoom || 16.5
                    })
                });
                var select = new ol.interaction.Select();
                map.addInteraction(select);
                var selectedFeatures = select.getFeatures();
                map.on('singleclick', function (evt) {
                    var coordinate = evt.coordinate;
                    var hdms = toStringHDMS(toLonLat(coordinate));
                    console.log(hdms, coordinate)
                });
                select.on('select', function (e) {
                    if (!e.selected[0]) { closer.onclick(); return };
                    var bd = e.selected[0].getProperties();
                    var coordinate = e.mapBrowserEvent.coordinate;
                    zhmap.selectFeature(bd)
                    overlay.setPosition(coordinate);
                });
            },
            selectFeature: null,
            smapping: function (rid, callback) {
                var data = {
                    regionId: rid
                }
                appService.get(urlMap.pgmMap, data,
                    function (res) {
                        if(!res.data[0]) return;
                        var obj = res.data[0];
                        obj.center = obj.center && obj.center.split(',')
                        obj.center =  obj.center && obj.center.map(s=>{return s*1})
                        obj.extents = obj.extents && obj.extents.split(',')
                        obj.extents = obj.extents &&obj.extents.map(s=>{return s*1})
                        callback(obj)
                    })
            }
        }
        return factory
    }])