

angular.module("app_service", [])
  .service('appService', ['$http', '$cordovaToast',  function ($http, $cordovaToast) {
    /**
     * @description 查询数据 Json字符串
     * @param  {[type]}   opts     [description]
     * @param  {Function} callback [description]
     * @return {[type]}            [description]
     */
    this.queryData = function (opts, callback, errorCallback, finallyCallback) {
      var defauts = {
        method: "get", // {String} 请求方式 "GET"."POST"
        url: "", // {String} 请求的URL地址
        params: {}, // {key,value} 请求参数，将在URL上被拼接成？key=value //传入json对象,转换成字符串
        data: {} // {key,value} 数据，将被放入请求内发送至服务器
      }
      opts = angular.extend(defauts, opts);
      var promise = $http(opts);
      //成功处理
      promise.success(function (data, status) {
        callback(data, status);
      }).finally(function () {
        finallyCallback && finallyCallback();
      });
      promise.error(function (data, status) {
        errorCallback && errorCallback(data, status);
        console.log(status);
        if (!errorCallback) { $cordovaToast && $cordovaToast.showShortCenter("网络错误"); return false; }
        return false;
      })
    }

    /**
     * @description delete 方式查询数据 Json对象
     * @param  url {String} 请求的URL地址  
     * @param  dataParam  {key,value} 数据，将被放入请求内发送至服务器
     * @return callback {[function]}    回调函数
     */
    this.deleteData = function (url, dataParam, callback, errorCallback, finallyCallback) {
      var opts = {
        method: "delete",
        url: url,
        headers: {
          'Content-Type': 'application/json'
        },
        data: dataParam
      }
      var promise = $http(opts);
      promise.success(function (data, status) {
        callback(data, status);
      }).finally(function (data, status) {
        finallyCallback && finallyCallback(data, status);
      });
      promise.error(function (data, status) {
        errorCallback && errorCallback(data, status);
        console.log(status);
        if (!errorCallback) { $cordovaToast && $cordovaToast.showShortCenter("网络错误"); return false; }
        return false;
      })
    }
    /**
     * @description post 方式查询数据 Json对象
     * @param  url {String} 请求的URL地址  
     * @param  dataParam  {key,value} 数据，将被放入请求内发送至服务器
     * @return callback {[function]}    回调函数
     */
    this.postData = function (url, dataParam, callback, errorCallback, finallyCallback) {
      var opts = {
        method: "post",
        url: url,
        data: dataParam
      }
      var promise = $http(opts);
      promise.success(function (data, status) {
        // console.log("ajax success方法回调");
        callback(data, status);
      }).finally(function (data, status) {
        finallyCallback && finallyCallback(data, status);
      });
      promise.error(function (data, status) {
        errorCallback && errorCallback(data, status);
        console.log(status);
        if (!errorCallback) { $cordovaToast && $cordovaToast.showShortCenter("网络错误"); return false; }
        return false;
      })
    }
    /**
     * @description put 方式更新数据 Json对象
     * @param  url {String} 请求的URL地址  
     * @param  dataParam  {key,value} 数据，将被放入请求内发送至服务器
     * @return callback {[function]}    回调函数
     */
    this.putData = function (url, dataParam, callback, errorCallback, finallyCallback) {
      var opts = {
        method: "put",
        url: url,
        data: dataParam
      }
      var promise = $http(opts);
      promise.success(function (data, status) {
        // console.log("ajax success方法回调");
        callback(data, status);
      }).finally(function (data, status) {
        finallyCallback && finallyCallback(data, status);
      });
      promise.error(function (data, status) {
        errorCallback && errorCallback(data, status);
        console.log(status);
        if (!errorCallback) { $cordovaToast && $cordovaToast.showShortCenter("网络错误"); return false; }
        return false;
      })
    }

    /**
     * @description get 方式查询数据
     * @param  url {String} 请求的URL地址  
     * @param  dataParam  {key,value} 数据，将被放入请求内发送至服务器
     * @return callback {[function]}    回调函数
     */
    this.getData = function (url, dataParam, callback, errorCallback, finallyCallback) {
      var opts = {
        method: "get",
        url: url,
        params: dataParam,
      }
      // console.log("getData 方法传递参数 :");
      // console.log(opts);
      var promise = $http(opts);
      //成功处理
      promise.success(function (data, status) {
        callback(data, status);
      }).finally(function () {
        finallyCallback && finallyCallback();
      });
      promise.error(function (data, status) {
        errorCallback && errorCallback(data, status);
        console.log(status);
        if (!errorCallback) { $cordovaToast && $cordovaToast.showShortCenter("网络错误"); return false; }
        return false;
      })
    }
    /**
     * @description get , 带Authorization
     */
    this.get = function (url, data, callback, errorCallback, finallyCallback) {
      data.mid = data.mid || 1;
      var opts = {
        method: "get",
        url: url,
        headers: {
          token: 'enp0aGFwcA==',
        },
        params: data,
      }
      var promise = $http(opts);
      //成功处理
      promise.success(function (data, status) {
        callback(data, status);
      }).finally(function () {
        finallyCallback && finallyCallback();
      });
      promise.error(function (data, status) {
        errorCallback && errorCallback(data, status);
        if (!errorCallback) { $cordovaToast && $cordovaToast.showShortCenter("网络错误"); return false; }
        return false;
      })
    }
    /**
     * @description post  带Authorization
     */
    this.post = function (url, data, callback, errorCallback, finallyCallback) {
      data.mid = data.mid || 1;
      var opts = {
        method: "post",
        url: url,
        headers: {
          token: 'enp0aGFwcA==',
        },
        data: data,
      }
      var promise = $http(opts);
      promise.success(function (data, status) {
        callback(data, status);
      }).finally(function () {
        finallyCallback && finallyCallback();
      });
      promise.error(function (data, status) {
        errorCallback && errorCallback(data, status);
        if (!errorCallback) { $cordovaToast && $cordovaToast.showShortCenter("网络错误"); return false; }
        return false;
      })
    }
    /**
     * @description put 带Authorization
     */
    this.put = function (url, data, callback, errorCallback, finallyCallback) {
      data.mid = data.mid || 1;
      var opts = {
        method: "put",
        url: url,
        headers: {
          token: 'enp0aGFwcA==',
        },
        data: data,
      }
      var promise = $http(opts);
      promise.success(function (data, status) {
        callback(data, status);
      }).finally(function () {
        finallyCallback && finallyCallback();
      });
      promise.error(function (data, status) {
        errorCallback && errorCallback(data, status);
        if (!errorCallback) { $cordovaToast && $cordovaToast.showShortCenter("网络错误"); return false; }
        return false;
      })
    }
  }]);
